/*
 * Copyright (C) 2023-2025 Xeme Developers
 *
 * Xeme is the legal property of its developers, whose names are too
 * numerous to list here. Please refer to the AUTHORS file distributed
 * with this source distribution
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, see
 * <https://www.gnu.org/licenses/>.
 */

#include "xemeversion.h"

/******************************************************************************
 * Externals
 *****************************************************************************/
const guint xeme_major_version = XEME_MAJOR_VERSION;
const guint xeme_minor_version = XEME_MINOR_VERSION;
const guint xeme_micro_version = XEME_MICRO_VERSION;
const char *xeme_version = XEME_VERSION;

/******************************************************************************
 * Public API
 *****************************************************************************/
const char *
xeme_check_version(guint required_major, guint required_minor,
                   guint required_micro)
{
	if(required_major > XEME_MAJOR_VERSION) {
		return "xeme version too old (major mismatch)";
	}

#if XEME_CHECK_VERSION(1, 0, 0)
	if(required_major < XEME_MAJOR_VERSION) {
		return "xeme version too new (major mismatch)";
	}
#endif

	if(required_minor > XEME_MINOR_VERSION) {
		return "xeme version too old (minor mismatch)";
	}

	if((required_minor == XEME_MINOR_VERSION) &&
	   (required_micro > XEME_MICRO_VERSION))
	{
		return "xeme version too old (micro mismatch)";
	}

	return NULL;
}
